@@ -1,4 +1,6 @@
+import os
 import typing as t
+import warnings
 from dataclasses import dataclass, field, fields
 
 from hatchling.builders.hooks.plugin.interface import BuildHookInterface
@@ -23,6 +25,7 @@ class JupyterBuildConfig:
     editable_build_kwargs: t.Mapping[str, str] = field(default_factory=dict)
     ensured_targets: t.List[str] = field(default_factory=list)
     skip_if_exists: t.List[str] = field(default_factory=list)
+    optional_editable_build: str = ""
 
 
 class JupyterBuildHook(BuildHookInterface):
@@ -33,7 +36,11 @@ class JupyterBuildHook(BuildHookInterface):
         log.info("Running jupyter-builder")
         if self.target_name not in ["wheel", "sdist"]:
             log.info(f"ignoring target name {self.target_name}")
-            return
+            return False
+
+        if os.getenv("SKIP_JUPYTER_BUILDER"):
+            log.info("Skipping the build hook since SKIP_JUPYTER_BUILDER was set")
+            return False
 
         kwargs = normalize_kwargs(self.config)
         available_fields = [f.name for f in fields(JupyterBuildConfig)]
@@ -67,7 +74,13 @@ class JupyterBuildHook(BuildHookInterface):
             build_kwargs = normalize_kwargs(build_kwargs)
             log.info(f"Building with {config.build_function}")
             log.info(f"With kwargs: {build_kwargs}")
-            build_func(self.target_name, version, **build_kwargs)
+            try:
+                build_func(self.target_name, version, **build_kwargs)
+            except Exception as e:
+                if version == "editable" and config.optional_editable_build.lower() == "true":
+                    warnings.warn(f"Encountered build error:\n{e}")
+                else:
+                    raise e
         else:
             log.info("Skipping build")
 
@@ -76,3 +89,4 @@ class JupyterBuildHook(BuildHookInterface):
             ensure_targets(config.ensured_targets)
 
         log.info("Finished running jupyter-builder")
+        return True
